@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 """Json Bourne -- EZ-PZ-JSON with lots o goodies"""
+from __future__ import annotations
+
 import keyword
 
 from functools import lru_cache
@@ -18,6 +20,7 @@ from typing import (
     Iterator,
     KeysView,
     List,
+    Mapping,
     MutableMapping,
     Optional,
     Set,
@@ -25,13 +28,14 @@ from typing import (
     Type,
     TypeVar,
     Union,
+    cast,
     overload,
 )
 
 from jsonbourne import jsonlib
 
 JsonPrimitiveT = TypeVar("JsonPrimitiveT", str, int, float, None)
-JsonObjT = TypeVar("JsonObjT", bound="JsonObj")
+JsonObjT = TypeVar("JsonObjT", bound="JsonObj[Any]")
 KT = TypeVar("KT")
 VT = TypeVar("VT")
 _KT = str
@@ -124,7 +128,7 @@ def is_number(value: Any) -> bool:
     return is_int(value) or is_float(value)
 
 
-class JsonObj(JsonObjMutableMapping, Generic[_VT]):
+class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
     """JSON friendly python dictionary with dot notation and string only keys
 
     JsonObj(foo='bar')['foo'] == JsonObj(foo='bar').foo
@@ -195,7 +199,26 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
 
     _data: Dict[_KT, _VT]
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
+    @overload
+    def __init__(
+        self,
+        *args: Mapping[_KT, _VT],
+    ) -> None:
+        ...
+
+    @overload
+    def __init__(
+        self,
+        *args: Mapping[_KT, _VT],
+        **kwargs: _VT,
+    ) -> None:
+        ...
+
+    def __init__(
+        self,
+        *args: Any,
+        **kwargs: _VT,
+    ) -> None:
         """Use the object dict"""
         _data = dict(*args, **kwargs)
         super().__setattr__("_data", _data)
@@ -399,7 +422,7 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
                 return default
             raise ke
 
-    def filter_none(self, recursive: bool = False) -> "JsonObj":
+    def filter_none(self, recursive: bool = False) -> JsonObj[_VT]:
         """Filter key-values where the value is `None` but not false-y
 
         Args:
@@ -474,17 +497,20 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
         """
         if recursive:
             return JsonObj(
-                {
-                    k: v
-                    if not isinstance(v, (dict, JsonObj))
-                    else JsonObj(v).filter_none(recursive=True)
-                    for k, v in self.items()
-                    if v is not None
-                }
+                cast(
+                    Dict[str, _VT],
+                    {
+                        k: v
+                        if not isinstance(v, (dict, JsonObj))
+                        else JsonObj(v).filter_none(recursive=True)
+                        for k, v in self.items()
+                        if v is not None
+                    },
+                )
             )
         return JsonObj({k: v for k, v in self.items() if v is not None})
 
-    def filter_false(self, recursive: bool = False) -> "JsonObj":
+    def filter_false(self, recursive: bool = False) -> JsonObj[_VT]:
         """Filter key-values where the value is false-y
 
         Args:
@@ -545,13 +571,16 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
         """
         if recursive:
             return JsonObj(
-                {
-                    k: v
-                    if not isinstance(v, (dict, JsonObj))
-                    else JsonObj(v).filter_false(recursive=True)
-                    for k, v in self.items()
-                    if v
-                }
+                cast(
+                    Dict[str, _VT],
+                    {
+                        k: v
+                        if not isinstance(v, (dict, JsonObj))
+                        else JsonObj(v).filter_false(recursive=True)
+                        for k, v in self.items()
+                        if v
+                    },
+                )
             )
         return JsonObj({k: v for k, v in self.items() if v})
 
@@ -809,12 +838,14 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
         return self.eject()
 
     @classmethod
-    def from_dict(cls: Type[JsonObjT], data: Dict[_KT, _VT]) -> JsonObjT:
+    def from_dict(cls: Type[JsonObj[_VT]], data: Dict[_KT, _VT]) -> JsonObj[_VT]:
         """Return a JsonObj object from a dictionary of data"""
         return cls(**data)
 
     @classmethod
-    def from_json(cls: Type[JsonObjT], json_string: Union[bytes, str]) -> JsonObjT:
+    def from_json(
+        cls: Type[JsonObj[_VT]], json_string: Union[bytes, str]
+    ) -> JsonObj[_VT]:
         """Return a JsonObj object from a json string
 
         Args:
@@ -827,7 +858,9 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
         return cls._from_json(json_string)
 
     @classmethod
-    def _from_json(cls: Type[JsonObjT], json_string: Union[bytes, str]) -> JsonObjT:
+    def _from_json(
+        cls: Type[JsonObj[_VT]], json_string: Union[bytes, str]
+    ) -> JsonObj[_VT]:
         """Return a JsonObj object from a json string
 
         Args:
@@ -971,7 +1004,7 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
         )
 
     @classmethod
-    def validate_type(cls: Type[JsonObjT], val: Any) -> JsonObjT:
+    def validate_type(cls: Type[JsonObj[_VT]], val: Any) -> JsonObj[_VT]:
         """Validate and convert a value to a JsonObj object"""
         return cls(val)
 
@@ -981,7 +1014,7 @@ class JsonObj(JsonObjMutableMapping, Generic[_VT]):
         yield cls.validate_type
 
 
-class JsonDict(JsonObj):
+class JsonDict(JsonObj[_VT], Generic[_VT]):
     """Alias for JsonObj"""
 
     pass
@@ -1063,6 +1096,9 @@ class JSON(metaclass=JSONMeta):
     Null = Null
     JSONDecodeError = JSONDecodeError
 
+    def __new__(cls, *args: Any, **kwargs: Any) -> Any:
+        return cls.__call__(*args, **kwargs)
+
     @staticmethod
     def stringify(
         data: Any,
